# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class LandslideViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dt_land_slide_time': 'datetime',
        'utm_north_stop': 'int',
        'utm_east_stop': 'int',
        'utm_zone_stop': 'int',
        'land_slide_tid': 'int',
        'land_slide_name': 'str',
        'land_slide_trigger_tid': 'int',
        'land_slide_trigger_name': 'str',
        'land_slide_size_tid': 'int',
        'land_slide_size_name': 'str',
        'comment': 'str',
        'dt_land_slide_time_end': 'datetime',
        'geo_hazard_tid': 'int',
        'geo_hazard_name': 'str',
        'activity_influenced_tid': 'int',
        'activity_influenced_name': 'str',
        'forecast_accurate_tid': 'int',
        'forecast_accurate_name': 'str',
        'damage_extent_tid': 'int',
        'damage_extent_name': 'str',
        'utm_zone_start': 'int',
        'utm_north_start': 'int',
        'utm_east_start': 'int',
        'dt_off_land_slide_time': 'datetime',
        'dt_off_land_slide_time_end': 'datetime',
        'urls': 'list[UrlViewModel]'
    }

    attribute_map = {
        'dt_land_slide_time': 'DtLandSlideTime',
        'utm_north_stop': 'UTMNorthStop',
        'utm_east_stop': 'UTMEastStop',
        'utm_zone_stop': 'UTMZoneStop',
        'land_slide_tid': 'LandSlideTID',
        'land_slide_name': 'LandSlideName',
        'land_slide_trigger_tid': 'LandSlideTriggerTID',
        'land_slide_trigger_name': 'LandSlideTriggerName',
        'land_slide_size_tid': 'LandSlideSizeTID',
        'land_slide_size_name': 'LandSlideSizeName',
        'comment': 'Comment',
        'dt_land_slide_time_end': 'DtLandSlideTimeEnd',
        'geo_hazard_tid': 'GeoHazardTID',
        'geo_hazard_name': 'GeoHazardName',
        'activity_influenced_tid': 'ActivityInfluencedTID',
        'activity_influenced_name': 'ActivityInfluencedName',
        'forecast_accurate_tid': 'ForecastAccurateTID',
        'forecast_accurate_name': 'ForecastAccurateName',
        'damage_extent_tid': 'DamageExtentTID',
        'damage_extent_name': 'DamageExtentName',
        'utm_zone_start': 'UTMZoneStart',
        'utm_north_start': 'UTMNorthStart',
        'utm_east_start': 'UTMEastStart',
        'dt_off_land_slide_time': 'DtOffLandSlideTime',
        'dt_off_land_slide_time_end': 'DtOffLandSlideTimeEnd',
        'urls': 'Urls'
    }

    def __init__(self, dt_land_slide_time=None, utm_north_stop=None, utm_east_stop=None, utm_zone_stop=None, land_slide_tid=None, land_slide_name=None, land_slide_trigger_tid=None, land_slide_trigger_name=None, land_slide_size_tid=None, land_slide_size_name=None, comment=None, dt_land_slide_time_end=None, geo_hazard_tid=None, geo_hazard_name=None, activity_influenced_tid=None, activity_influenced_name=None, forecast_accurate_tid=None, forecast_accurate_name=None, damage_extent_tid=None, damage_extent_name=None, utm_zone_start=None, utm_north_start=None, utm_east_start=None, dt_off_land_slide_time=None, dt_off_land_slide_time_end=None, urls=None):  # noqa: E501
        """LandslideViewModel - a model defined in Swagger"""  # noqa: E501
        self._dt_land_slide_time = None
        self._utm_north_stop = None
        self._utm_east_stop = None
        self._utm_zone_stop = None
        self._land_slide_tid = None
        self._land_slide_name = None
        self._land_slide_trigger_tid = None
        self._land_slide_trigger_name = None
        self._land_slide_size_tid = None
        self._land_slide_size_name = None
        self._comment = None
        self._dt_land_slide_time_end = None
        self._geo_hazard_tid = None
        self._geo_hazard_name = None
        self._activity_influenced_tid = None
        self._activity_influenced_name = None
        self._forecast_accurate_tid = None
        self._forecast_accurate_name = None
        self._damage_extent_tid = None
        self._damage_extent_name = None
        self._utm_zone_start = None
        self._utm_north_start = None
        self._utm_east_start = None
        self._dt_off_land_slide_time = None
        self._dt_off_land_slide_time_end = None
        self._urls = None
        self.discriminator = None
        if dt_land_slide_time is not None:
            self.dt_land_slide_time = dt_land_slide_time
        if utm_north_stop is not None:
            self.utm_north_stop = utm_north_stop
        if utm_east_stop is not None:
            self.utm_east_stop = utm_east_stop
        if utm_zone_stop is not None:
            self.utm_zone_stop = utm_zone_stop
        if land_slide_tid is not None:
            self.land_slide_tid = land_slide_tid
        if land_slide_name is not None:
            self.land_slide_name = land_slide_name
        if land_slide_trigger_tid is not None:
            self.land_slide_trigger_tid = land_slide_trigger_tid
        if land_slide_trigger_name is not None:
            self.land_slide_trigger_name = land_slide_trigger_name
        if land_slide_size_tid is not None:
            self.land_slide_size_tid = land_slide_size_tid
        if land_slide_size_name is not None:
            self.land_slide_size_name = land_slide_size_name
        if comment is not None:
            self.comment = comment
        if dt_land_slide_time_end is not None:
            self.dt_land_slide_time_end = dt_land_slide_time_end
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if geo_hazard_name is not None:
            self.geo_hazard_name = geo_hazard_name
        if activity_influenced_tid is not None:
            self.activity_influenced_tid = activity_influenced_tid
        if activity_influenced_name is not None:
            self.activity_influenced_name = activity_influenced_name
        if forecast_accurate_tid is not None:
            self.forecast_accurate_tid = forecast_accurate_tid
        if forecast_accurate_name is not None:
            self.forecast_accurate_name = forecast_accurate_name
        if damage_extent_tid is not None:
            self.damage_extent_tid = damage_extent_tid
        if damage_extent_name is not None:
            self.damage_extent_name = damage_extent_name
        if utm_zone_start is not None:
            self.utm_zone_start = utm_zone_start
        if utm_north_start is not None:
            self.utm_north_start = utm_north_start
        if utm_east_start is not None:
            self.utm_east_start = utm_east_start
        if dt_off_land_slide_time is not None:
            self.dt_off_land_slide_time = dt_off_land_slide_time
        if dt_off_land_slide_time_end is not None:
            self.dt_off_land_slide_time_end = dt_off_land_slide_time_end
        if urls is not None:
            self.urls = urls

    @property
    def dt_land_slide_time(self):
        """Gets the dt_land_slide_time of this LandslideViewModel.  # noqa: E501


        :return: The dt_land_slide_time of this LandslideViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_land_slide_time

    @dt_land_slide_time.setter
    def dt_land_slide_time(self, dt_land_slide_time):
        """Sets the dt_land_slide_time of this LandslideViewModel.


        :param dt_land_slide_time: The dt_land_slide_time of this LandslideViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_land_slide_time = dt_land_slide_time

    @property
    def utm_north_stop(self):
        """Gets the utm_north_stop of this LandslideViewModel.  # noqa: E501


        :return: The utm_north_stop of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_north_stop

    @utm_north_stop.setter
    def utm_north_stop(self, utm_north_stop):
        """Sets the utm_north_stop of this LandslideViewModel.


        :param utm_north_stop: The utm_north_stop of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._utm_north_stop = utm_north_stop

    @property
    def utm_east_stop(self):
        """Gets the utm_east_stop of this LandslideViewModel.  # noqa: E501


        :return: The utm_east_stop of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_east_stop

    @utm_east_stop.setter
    def utm_east_stop(self, utm_east_stop):
        """Sets the utm_east_stop of this LandslideViewModel.


        :param utm_east_stop: The utm_east_stop of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._utm_east_stop = utm_east_stop

    @property
    def utm_zone_stop(self):
        """Gets the utm_zone_stop of this LandslideViewModel.  # noqa: E501


        :return: The utm_zone_stop of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone_stop

    @utm_zone_stop.setter
    def utm_zone_stop(self, utm_zone_stop):
        """Sets the utm_zone_stop of this LandslideViewModel.


        :param utm_zone_stop: The utm_zone_stop of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._utm_zone_stop = utm_zone_stop

    @property
    def land_slide_tid(self):
        """Gets the land_slide_tid of this LandslideViewModel.  # noqa: E501


        :return: The land_slide_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._land_slide_tid

    @land_slide_tid.setter
    def land_slide_tid(self, land_slide_tid):
        """Sets the land_slide_tid of this LandslideViewModel.


        :param land_slide_tid: The land_slide_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._land_slide_tid = land_slide_tid

    @property
    def land_slide_name(self):
        """Gets the land_slide_name of this LandslideViewModel.  # noqa: E501


        :return: The land_slide_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._land_slide_name

    @land_slide_name.setter
    def land_slide_name(self, land_slide_name):
        """Sets the land_slide_name of this LandslideViewModel.


        :param land_slide_name: The land_slide_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._land_slide_name = land_slide_name

    @property
    def land_slide_trigger_tid(self):
        """Gets the land_slide_trigger_tid of this LandslideViewModel.  # noqa: E501


        :return: The land_slide_trigger_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._land_slide_trigger_tid

    @land_slide_trigger_tid.setter
    def land_slide_trigger_tid(self, land_slide_trigger_tid):
        """Sets the land_slide_trigger_tid of this LandslideViewModel.


        :param land_slide_trigger_tid: The land_slide_trigger_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._land_slide_trigger_tid = land_slide_trigger_tid

    @property
    def land_slide_trigger_name(self):
        """Gets the land_slide_trigger_name of this LandslideViewModel.  # noqa: E501


        :return: The land_slide_trigger_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._land_slide_trigger_name

    @land_slide_trigger_name.setter
    def land_slide_trigger_name(self, land_slide_trigger_name):
        """Sets the land_slide_trigger_name of this LandslideViewModel.


        :param land_slide_trigger_name: The land_slide_trigger_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._land_slide_trigger_name = land_slide_trigger_name

    @property
    def land_slide_size_tid(self):
        """Gets the land_slide_size_tid of this LandslideViewModel.  # noqa: E501


        :return: The land_slide_size_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._land_slide_size_tid

    @land_slide_size_tid.setter
    def land_slide_size_tid(self, land_slide_size_tid):
        """Sets the land_slide_size_tid of this LandslideViewModel.


        :param land_slide_size_tid: The land_slide_size_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._land_slide_size_tid = land_slide_size_tid

    @property
    def land_slide_size_name(self):
        """Gets the land_slide_size_name of this LandslideViewModel.  # noqa: E501


        :return: The land_slide_size_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._land_slide_size_name

    @land_slide_size_name.setter
    def land_slide_size_name(self, land_slide_size_name):
        """Sets the land_slide_size_name of this LandslideViewModel.


        :param land_slide_size_name: The land_slide_size_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._land_slide_size_name = land_slide_size_name

    @property
    def comment(self):
        """Gets the comment of this LandslideViewModel.  # noqa: E501


        :return: The comment of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this LandslideViewModel.


        :param comment: The comment of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def dt_land_slide_time_end(self):
        """Gets the dt_land_slide_time_end of this LandslideViewModel.  # noqa: E501


        :return: The dt_land_slide_time_end of this LandslideViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_land_slide_time_end

    @dt_land_slide_time_end.setter
    def dt_land_slide_time_end(self, dt_land_slide_time_end):
        """Sets the dt_land_slide_time_end of this LandslideViewModel.


        :param dt_land_slide_time_end: The dt_land_slide_time_end of this LandslideViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_land_slide_time_end = dt_land_slide_time_end

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this LandslideViewModel.  # noqa: E501


        :return: The geo_hazard_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this LandslideViewModel.


        :param geo_hazard_tid: The geo_hazard_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def geo_hazard_name(self):
        """Gets the geo_hazard_name of this LandslideViewModel.  # noqa: E501


        :return: The geo_hazard_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._geo_hazard_name

    @geo_hazard_name.setter
    def geo_hazard_name(self, geo_hazard_name):
        """Sets the geo_hazard_name of this LandslideViewModel.


        :param geo_hazard_name: The geo_hazard_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._geo_hazard_name = geo_hazard_name

    @property
    def activity_influenced_tid(self):
        """Gets the activity_influenced_tid of this LandslideViewModel.  # noqa: E501


        :return: The activity_influenced_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._activity_influenced_tid

    @activity_influenced_tid.setter
    def activity_influenced_tid(self, activity_influenced_tid):
        """Sets the activity_influenced_tid of this LandslideViewModel.


        :param activity_influenced_tid: The activity_influenced_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._activity_influenced_tid = activity_influenced_tid

    @property
    def activity_influenced_name(self):
        """Gets the activity_influenced_name of this LandslideViewModel.  # noqa: E501


        :return: The activity_influenced_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._activity_influenced_name

    @activity_influenced_name.setter
    def activity_influenced_name(self, activity_influenced_name):
        """Sets the activity_influenced_name of this LandslideViewModel.


        :param activity_influenced_name: The activity_influenced_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._activity_influenced_name = activity_influenced_name

    @property
    def forecast_accurate_tid(self):
        """Gets the forecast_accurate_tid of this LandslideViewModel.  # noqa: E501


        :return: The forecast_accurate_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._forecast_accurate_tid

    @forecast_accurate_tid.setter
    def forecast_accurate_tid(self, forecast_accurate_tid):
        """Sets the forecast_accurate_tid of this LandslideViewModel.


        :param forecast_accurate_tid: The forecast_accurate_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._forecast_accurate_tid = forecast_accurate_tid

    @property
    def forecast_accurate_name(self):
        """Gets the forecast_accurate_name of this LandslideViewModel.  # noqa: E501


        :return: The forecast_accurate_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._forecast_accurate_name

    @forecast_accurate_name.setter
    def forecast_accurate_name(self, forecast_accurate_name):
        """Sets the forecast_accurate_name of this LandslideViewModel.


        :param forecast_accurate_name: The forecast_accurate_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._forecast_accurate_name = forecast_accurate_name

    @property
    def damage_extent_tid(self):
        """Gets the damage_extent_tid of this LandslideViewModel.  # noqa: E501


        :return: The damage_extent_tid of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._damage_extent_tid

    @damage_extent_tid.setter
    def damage_extent_tid(self, damage_extent_tid):
        """Sets the damage_extent_tid of this LandslideViewModel.


        :param damage_extent_tid: The damage_extent_tid of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._damage_extent_tid = damage_extent_tid

    @property
    def damage_extent_name(self):
        """Gets the damage_extent_name of this LandslideViewModel.  # noqa: E501


        :return: The damage_extent_name of this LandslideViewModel.  # noqa: E501
        :rtype: str
        """
        return self._damage_extent_name

    @damage_extent_name.setter
    def damage_extent_name(self, damage_extent_name):
        """Sets the damage_extent_name of this LandslideViewModel.


        :param damage_extent_name: The damage_extent_name of this LandslideViewModel.  # noqa: E501
        :type: str
        """

        self._damage_extent_name = damage_extent_name

    @property
    def utm_zone_start(self):
        """Gets the utm_zone_start of this LandslideViewModel.  # noqa: E501


        :return: The utm_zone_start of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_zone_start

    @utm_zone_start.setter
    def utm_zone_start(self, utm_zone_start):
        """Sets the utm_zone_start of this LandslideViewModel.


        :param utm_zone_start: The utm_zone_start of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._utm_zone_start = utm_zone_start

    @property
    def utm_north_start(self):
        """Gets the utm_north_start of this LandslideViewModel.  # noqa: E501


        :return: The utm_north_start of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_north_start

    @utm_north_start.setter
    def utm_north_start(self, utm_north_start):
        """Sets the utm_north_start of this LandslideViewModel.


        :param utm_north_start: The utm_north_start of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._utm_north_start = utm_north_start

    @property
    def utm_east_start(self):
        """Gets the utm_east_start of this LandslideViewModel.  # noqa: E501


        :return: The utm_east_start of this LandslideViewModel.  # noqa: E501
        :rtype: int
        """
        return self._utm_east_start

    @utm_east_start.setter
    def utm_east_start(self, utm_east_start):
        """Sets the utm_east_start of this LandslideViewModel.


        :param utm_east_start: The utm_east_start of this LandslideViewModel.  # noqa: E501
        :type: int
        """

        self._utm_east_start = utm_east_start

    @property
    def dt_off_land_slide_time(self):
        """Gets the dt_off_land_slide_time of this LandslideViewModel.  # noqa: E501


        :return: The dt_off_land_slide_time of this LandslideViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_off_land_slide_time

    @dt_off_land_slide_time.setter
    def dt_off_land_slide_time(self, dt_off_land_slide_time):
        """Sets the dt_off_land_slide_time of this LandslideViewModel.


        :param dt_off_land_slide_time: The dt_off_land_slide_time of this LandslideViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_off_land_slide_time = dt_off_land_slide_time

    @property
    def dt_off_land_slide_time_end(self):
        """Gets the dt_off_land_slide_time_end of this LandslideViewModel.  # noqa: E501


        :return: The dt_off_land_slide_time_end of this LandslideViewModel.  # noqa: E501
        :rtype: datetime
        """
        return self._dt_off_land_slide_time_end

    @dt_off_land_slide_time_end.setter
    def dt_off_land_slide_time_end(self, dt_off_land_slide_time_end):
        """Sets the dt_off_land_slide_time_end of this LandslideViewModel.


        :param dt_off_land_slide_time_end: The dt_off_land_slide_time_end of this LandslideViewModel.  # noqa: E501
        :type: datetime
        """

        self._dt_off_land_slide_time_end = dt_off_land_slide_time_end

    @property
    def urls(self):
        """Gets the urls of this LandslideViewModel.  # noqa: E501


        :return: The urls of this LandslideViewModel.  # noqa: E501
        :rtype: list[UrlViewModel]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this LandslideViewModel.


        :param urls: The urls of this LandslideViewModel.  # noqa: E501
        :type: list[UrlViewModel]
        """

        self._urls = urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LandslideViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LandslideViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from varsom_regobs_client.api_client import ApiClient


class RegistrationApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def registration_get(self, reg_id, lang_key, **kwargs):  # noqa: E501
        """Get registration by regId.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_get(reg_id, lang_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int reg_id: Registration Id (required)
        :param int lang_key: 1 = norwegian, 2 = english (required)
        :return: RegistrationViewModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registration_get_with_http_info(reg_id, lang_key, **kwargs)  # noqa: E501
        else:
            (data) = self.registration_get_with_http_info(reg_id, lang_key, **kwargs)  # noqa: E501
            return data

    def registration_get_with_http_info(self, reg_id, lang_key, **kwargs):  # noqa: E501
        """Get registration by regId.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_get_with_http_info(reg_id, lang_key, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int reg_id: Registration Id (required)
        :param int lang_key: 1 = norwegian, 2 = english (required)
        :return: RegistrationViewModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reg_id', 'lang_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registration_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reg_id' is set
        if ('reg_id' not in params or
                params['reg_id'] is None):
            raise ValueError("Missing the required parameter `reg_id` when calling `registration_get`")  # noqa: E501
        # verify the required parameter 'lang_key' is set
        if ('lang_key' not in params or
                params['lang_key'] is None):
            raise ValueError("Missing the required parameter `lang_key` when calling `registration_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'reg_id' in params:
            path_params['regId'] = params['reg_id']  # noqa: E501
        if 'lang_key' in params:
            path_params['langKey'] = params['lang_key']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Registration/{regId}/{langKey}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RegistrationViewModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registration_get_caaml(self, reg_id, **kwargs):  # noqa: E501
        """Get a registration in CAAML format  # noqa: E501

        CAAML (Canadian Avalanche Association Markup Language) is a standard   for the electronic representation of information pertinent to avalanche   safety operations. See http://caaml.org/.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_get_caaml(reg_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int reg_id: Registration Id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registration_get_caaml_with_http_info(reg_id, **kwargs)  # noqa: E501
        else:
            (data) = self.registration_get_caaml_with_http_info(reg_id, **kwargs)  # noqa: E501
            return data

    def registration_get_caaml_with_http_info(self, reg_id, **kwargs):  # noqa: E501
        """Get a registration in CAAML format  # noqa: E501

        CAAML (Canadian Avalanche Association Markup Language) is a standard   for the electronic representation of information pertinent to avalanche   safety operations. See http://caaml.org/.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_get_caaml_with_http_info(reg_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int reg_id: Registration Id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['reg_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registration_get_caaml" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'reg_id' is set
        if ('reg_id' not in params or
                params['reg_id'] is None):
            raise ValueError("Missing the required parameter `reg_id` when calling `registration_get_caaml`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'reg_id' in params:
            path_params['regId'] = params['reg_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Registration/Caaml/{regId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registration_insert(self, body, **kwargs):  # noqa: E501
        """Create a new registration.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_insert(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegistrationRequestDto body: Registration data (required)
        :return: CreateRegistrationResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registration_insert_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.registration_insert_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def registration_insert_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a new registration.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_insert_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegistrationRequestDto body: Registration data (required)
        :return: CreateRegistrationResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registration_insert" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `registration_insert`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Registration', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateRegistrationResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registration_plot_preview_png(self, body, format, height, width, **kwargs):  # noqa: E501
        """Generate a preview figure for a snow profile registration.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_plot_preview_png(body, format, height, width, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegistrationRequestDto body: Snow profile registration (required)
        :param int format: (required)
        :param int height: (required)
        :param int width: (required)
        :param int lang_key: 1 = norwegian, 2 = english
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registration_plot_preview_png_with_http_info(body, format, height, width, **kwargs)  # noqa: E501
        else:
            (data) = self.registration_plot_preview_png_with_http_info(body, format, height, width, **kwargs)  # noqa: E501
            return data

    def registration_plot_preview_png_with_http_info(self, body, format, height, width, **kwargs):  # noqa: E501
        """Generate a preview figure for a snow profile registration.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_plot_preview_png_with_http_info(body, format, height, width, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegistrationRequestDto body: Snow profile registration (required)
        :param int format: (required)
        :param int height: (required)
        :param int width: (required)
        :param int lang_key: 1 = norwegian, 2 = english
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'format', 'height', 'width', 'lang_key']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registration_plot_preview_png" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `registration_plot_preview_png`")  # noqa: E501
        # verify the required parameter 'format' is set
        if ('format' not in params or
                params['format'] is None):
            raise ValueError("Missing the required parameter `format` when calling `registration_plot_preview_png`")  # noqa: E501
        # verify the required parameter 'height' is set
        if ('height' not in params or
                params['height'] is None):
            raise ValueError("Missing the required parameter `height` when calling `registration_plot_preview_png`")  # noqa: E501
        # verify the required parameter 'width' is set
        if ('width' not in params or
                params['width'] is None):
            raise ValueError("Missing the required parameter `width` when calling `registration_plot_preview_png`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'format' in params:
            query_params.append(('format', params['format']))  # noqa: E501
        if 'height' in params:
            query_params.append(('height', params['height']))  # noqa: E501
        if 'width' in params:
            query_params.append(('width', params['width']))  # noqa: E501
        if 'lang_key' in params:
            query_params.append(('langKey', params['lang_key']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Registration/PlotPreviewPng', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def registration_validate(self, body, **kwargs):  # noqa: E501
        """Validate registration data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_validate(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegistrationRequestDto body: Registration data (required)
        :return: CreateRegistrationResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.registration_validate_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.registration_validate_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def registration_validate_with_http_info(self, body, **kwargs):  # noqa: E501
        """Validate registration data.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.registration_validate_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateRegistrationRequestDto body: Registration data (required)
        :return: CreateRegistrationResponseDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method registration_validate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `registration_validate`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Registration/Validate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateRegistrationResponseDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class SnowSurfaceObservationDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'snow_depth': 'float',
        'new_snow_depth24': 'float',
        'new_snow_line': 'int',
        'snow_drift_tid': 'int',
        'height_limit_layered_snow': 'float',
        'snow_line': 'int',
        'snow_surface_tid': 'int',
        'surface_water_content_tid': 'int',
        'usage_flag_tid': 'int',
        'comment': 'str'
    }

    attribute_map = {
        'snow_depth': 'SnowDepth',
        'new_snow_depth24': 'NewSnowDepth24',
        'new_snow_line': 'NewSnowLine',
        'snow_drift_tid': 'SnowDriftTID',
        'height_limit_layered_snow': 'HeightLimitLayeredSnow',
        'snow_line': 'SnowLine',
        'snow_surface_tid': 'SnowSurfaceTID',
        'surface_water_content_tid': 'SurfaceWaterContentTID',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment'
    }

    def __init__(self, snow_depth=None, new_snow_depth24=None, new_snow_line=None, snow_drift_tid=None, height_limit_layered_snow=None, snow_line=None, snow_surface_tid=None, surface_water_content_tid=None, usage_flag_tid=None, comment=None):  # noqa: E501
        """SnowSurfaceObservationDto - a model defined in Swagger"""  # noqa: E501
        self._snow_depth = None
        self._new_snow_depth24 = None
        self._new_snow_line = None
        self._snow_drift_tid = None
        self._height_limit_layered_snow = None
        self._snow_line = None
        self._snow_surface_tid = None
        self._surface_water_content_tid = None
        self._usage_flag_tid = None
        self._comment = None
        self.discriminator = None
        if snow_depth is not None:
            self.snow_depth = snow_depth
        if new_snow_depth24 is not None:
            self.new_snow_depth24 = new_snow_depth24
        if new_snow_line is not None:
            self.new_snow_line = new_snow_line
        if snow_drift_tid is not None:
            self.snow_drift_tid = snow_drift_tid
        if height_limit_layered_snow is not None:
            self.height_limit_layered_snow = height_limit_layered_snow
        if snow_line is not None:
            self.snow_line = snow_line
        if snow_surface_tid is not None:
            self.snow_surface_tid = snow_surface_tid
        if surface_water_content_tid is not None:
            self.surface_water_content_tid = surface_water_content_tid
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment

    @property
    def snow_depth(self):
        """Gets the snow_depth of this SnowSurfaceObservationDto.  # noqa: E501

        Total snødybde i cm. Vi ønsker et gjennomsnitt for området.  # noqa: E501

        :return: The snow_depth of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: float
        """
        return self._snow_depth

    @snow_depth.setter
    def snow_depth(self, snow_depth):
        """Sets the snow_depth of this SnowSurfaceObservationDto.

        Total snødybde i cm. Vi ønsker et gjennomsnitt for området.  # noqa: E501

        :param snow_depth: The snow_depth of this SnowSurfaceObservationDto.  # noqa: E501
        :type: float
        """

        self._snow_depth = snow_depth

    @property
    def new_snow_depth24(self):
        """Gets the new_snow_depth24 of this SnowSurfaceObservationDto.  # noqa: E501

        Nysnødybde i cm. Vi ønsker et gjennomsnitt for området  # noqa: E501

        :return: The new_snow_depth24 of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: float
        """
        return self._new_snow_depth24

    @new_snow_depth24.setter
    def new_snow_depth24(self, new_snow_depth24):
        """Sets the new_snow_depth24 of this SnowSurfaceObservationDto.

        Nysnødybde i cm. Vi ønsker et gjennomsnitt for området  # noqa: E501

        :param new_snow_depth24: The new_snow_depth24 of this SnowSurfaceObservationDto.  # noqa: E501
        :type: float
        """

        self._new_snow_depth24 = new_snow_depth24

    @property
    def new_snow_line(self):
        """Gets the new_snow_line of this SnowSurfaceObservationDto.  # noqa: E501

        Nysnøgrensa. Hvor faller nedbør som snø? Meter over havet.  # noqa: E501

        :return: The new_snow_line of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: int
        """
        return self._new_snow_line

    @new_snow_line.setter
    def new_snow_line(self, new_snow_line):
        """Sets the new_snow_line of this SnowSurfaceObservationDto.

        Nysnøgrensa. Hvor faller nedbør som snø? Meter over havet.  # noqa: E501

        :param new_snow_line: The new_snow_line of this SnowSurfaceObservationDto.  # noqa: E501
        :type: int
        """

        self._new_snow_line = new_snow_line

    @property
    def snow_drift_tid(self):
        """Gets the snow_drift_tid of this SnowSurfaceObservationDto.  # noqa: E501

        Hvor mye har vinden transportert snøen? Valg fra nedtrekksmeny. The SnowDriftKD unique identifier  # noqa: E501

        :return: The snow_drift_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: int
        """
        return self._snow_drift_tid

    @snow_drift_tid.setter
    def snow_drift_tid(self, snow_drift_tid):
        """Sets the snow_drift_tid of this SnowSurfaceObservationDto.

        Hvor mye har vinden transportert snøen? Valg fra nedtrekksmeny. The SnowDriftKD unique identifier  # noqa: E501

        :param snow_drift_tid: The snow_drift_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :type: int
        """

        self._snow_drift_tid = snow_drift_tid

    @property
    def height_limit_layered_snow(self):
        """Gets the height_limit_layered_snow of this SnowSurfaceObservationDto.  # noqa: E501

        Grense lagdelt snø (moh)  # noqa: E501

        :return: The height_limit_layered_snow of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: float
        """
        return self._height_limit_layered_snow

    @height_limit_layered_snow.setter
    def height_limit_layered_snow(self, height_limit_layered_snow):
        """Sets the height_limit_layered_snow of this SnowSurfaceObservationDto.

        Grense lagdelt snø (moh)  # noqa: E501

        :param height_limit_layered_snow: The height_limit_layered_snow of this SnowSurfaceObservationDto.  # noqa: E501
        :type: float
        """

        self._height_limit_layered_snow = height_limit_layered_snow

    @property
    def snow_line(self):
        """Gets the snow_line of this SnowSurfaceObservationDto.  # noqa: E501

        Snøgrense (moh)  # noqa: E501

        :return: The snow_line of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: int
        """
        return self._snow_line

    @snow_line.setter
    def snow_line(self, snow_line):
        """Sets the snow_line of this SnowSurfaceObservationDto.

        Snøgrense (moh)  # noqa: E501

        :param snow_line: The snow_line of this SnowSurfaceObservationDto.  # noqa: E501
        :type: int
        """

        self._snow_line = snow_line

    @property
    def snow_surface_tid(self):
        """Gets the snow_surface_tid of this SnowSurfaceObservationDto.  # noqa: E501

        Snødekkehardhet  # noqa: E501

        :return: The snow_surface_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: int
        """
        return self._snow_surface_tid

    @snow_surface_tid.setter
    def snow_surface_tid(self, snow_surface_tid):
        """Sets the snow_surface_tid of this SnowSurfaceObservationDto.

        Snødekkehardhet  # noqa: E501

        :param snow_surface_tid: The snow_surface_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :type: int
        """

        self._snow_surface_tid = snow_surface_tid

    @property
    def surface_water_content_tid(self):
        """Gets the surface_water_content_tid of this SnowSurfaceObservationDto.  # noqa: E501

        Overflatefuktighet  # noqa: E501

        :return: The surface_water_content_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: int
        """
        return self._surface_water_content_tid

    @surface_water_content_tid.setter
    def surface_water_content_tid(self, surface_water_content_tid):
        """Sets the surface_water_content_tid of this SnowSurfaceObservationDto.

        Overflatefuktighet  # noqa: E501

        :param surface_water_content_tid: The surface_water_content_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :type: int
        """

        self._surface_water_content_tid = surface_water_content_tid

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this SnowSurfaceObservationDto.  # noqa: E501

        Bruksflagg  # noqa: E501

        :return: The usage_flag_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this SnowSurfaceObservationDto.

        Bruksflagg  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this SnowSurfaceObservationDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this SnowSurfaceObservationDto.  # noqa: E501

        Kommentarfelt for å skrive utfyllende tekst om observasjonen.  # noqa: E501

        :return: The comment of this SnowSurfaceObservationDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SnowSurfaceObservationDto.

        Kommentarfelt for å skrive utfyllende tekst om observasjonen.  # noqa: E501

        :param comment: The comment of this SnowSurfaceObservationDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnowSurfaceObservationDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnowSurfaceObservationDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheEvaluation2ViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_danger_name': 'str',
        'valid_exposition': 'str',
        'comment': 'str',
        'avalanche_evaluation': 'str',
        'avalanche_development': 'str',
        'exposed_height1': 'int',
        'exposed_height2': 'int',
        'exposed_height_combo_tid': 'int',
        'exposed_height_combo_name': 'str',
        'exposed_climate_tid': 'int',
        'exposed_climate_name': 'str',
        'avalanche_danger_tid': 'int',
        'avalanche_eval_problems': 'list[AvalancheEvalProblemViewModel]'
    }

    attribute_map = {
        'avalanche_danger_name': 'AvalancheDangerName',
        'valid_exposition': 'ValidExposition',
        'comment': 'Comment',
        'avalanche_evaluation': 'AvalancheEvaluation',
        'avalanche_development': 'AvalancheDevelopment',
        'exposed_height1': 'ExposedHeight1',
        'exposed_height2': 'ExposedHeight2',
        'exposed_height_combo_tid': 'ExposedHeightComboTID',
        'exposed_height_combo_name': 'ExposedHeightComboName',
        'exposed_climate_tid': 'ExposedClimateTID',
        'exposed_climate_name': 'ExposedClimateName',
        'avalanche_danger_tid': 'AvalancheDangerTID',
        'avalanche_eval_problems': 'AvalancheEvalProblems'
    }

    def __init__(self, avalanche_danger_name=None, valid_exposition=None, comment=None, avalanche_evaluation=None, avalanche_development=None, exposed_height1=None, exposed_height2=None, exposed_height_combo_tid=None, exposed_height_combo_name=None, exposed_climate_tid=None, exposed_climate_name=None, avalanche_danger_tid=None, avalanche_eval_problems=None):  # noqa: E501
        """AvalancheEvaluation2ViewModel - a model defined in Swagger"""  # noqa: E501
        self._avalanche_danger_name = None
        self._valid_exposition = None
        self._comment = None
        self._avalanche_evaluation = None
        self._avalanche_development = None
        self._exposed_height1 = None
        self._exposed_height2 = None
        self._exposed_height_combo_tid = None
        self._exposed_height_combo_name = None
        self._exposed_climate_tid = None
        self._exposed_climate_name = None
        self._avalanche_danger_tid = None
        self._avalanche_eval_problems = None
        self.discriminator = None
        if avalanche_danger_name is not None:
            self.avalanche_danger_name = avalanche_danger_name
        if valid_exposition is not None:
            self.valid_exposition = valid_exposition
        if comment is not None:
            self.comment = comment
        if avalanche_evaluation is not None:
            self.avalanche_evaluation = avalanche_evaluation
        if avalanche_development is not None:
            self.avalanche_development = avalanche_development
        if exposed_height1 is not None:
            self.exposed_height1 = exposed_height1
        if exposed_height2 is not None:
            self.exposed_height2 = exposed_height2
        if exposed_height_combo_tid is not None:
            self.exposed_height_combo_tid = exposed_height_combo_tid
        if exposed_height_combo_name is not None:
            self.exposed_height_combo_name = exposed_height_combo_name
        if exposed_climate_tid is not None:
            self.exposed_climate_tid = exposed_climate_tid
        if exposed_climate_name is not None:
            self.exposed_climate_name = exposed_climate_name
        if avalanche_danger_tid is not None:
            self.avalanche_danger_tid = avalanche_danger_tid
        if avalanche_eval_problems is not None:
            self.avalanche_eval_problems = avalanche_eval_problems

    @property
    def avalanche_danger_name(self):
        """Gets the avalanche_danger_name of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The avalanche_danger_name of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_danger_name

    @avalanche_danger_name.setter
    def avalanche_danger_name(self, avalanche_danger_name):
        """Sets the avalanche_danger_name of this AvalancheEvaluation2ViewModel.


        :param avalanche_danger_name: The avalanche_danger_name of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_danger_name = avalanche_danger_name

    @property
    def valid_exposition(self):
        """Gets the valid_exposition of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The valid_exposition of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._valid_exposition

    @valid_exposition.setter
    def valid_exposition(self, valid_exposition):
        """Sets the valid_exposition of this AvalancheEvaluation2ViewModel.


        :param valid_exposition: The valid_exposition of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._valid_exposition = valid_exposition

    @property
    def comment(self):
        """Gets the comment of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The comment of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheEvaluation2ViewModel.


        :param comment: The comment of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def avalanche_evaluation(self):
        """Gets the avalanche_evaluation of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The avalanche_evaluation of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_evaluation

    @avalanche_evaluation.setter
    def avalanche_evaluation(self, avalanche_evaluation):
        """Sets the avalanche_evaluation of this AvalancheEvaluation2ViewModel.


        :param avalanche_evaluation: The avalanche_evaluation of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_evaluation = avalanche_evaluation

    @property
    def avalanche_development(self):
        """Gets the avalanche_development of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The avalanche_development of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_development

    @avalanche_development.setter
    def avalanche_development(self, avalanche_development):
        """Sets the avalanche_development of this AvalancheEvaluation2ViewModel.


        :param avalanche_development: The avalanche_development of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_development = avalanche_development

    @property
    def exposed_height1(self):
        """Gets the exposed_height1 of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The exposed_height1 of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height1

    @exposed_height1.setter
    def exposed_height1(self, exposed_height1):
        """Sets the exposed_height1 of this AvalancheEvaluation2ViewModel.


        :param exposed_height1: The exposed_height1 of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height1 = exposed_height1

    @property
    def exposed_height2(self):
        """Gets the exposed_height2 of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The exposed_height2 of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height2

    @exposed_height2.setter
    def exposed_height2(self, exposed_height2):
        """Sets the exposed_height2 of this AvalancheEvaluation2ViewModel.


        :param exposed_height2: The exposed_height2 of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height2 = exposed_height2

    @property
    def exposed_height_combo_tid(self):
        """Gets the exposed_height_combo_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The exposed_height_combo_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_height_combo_tid

    @exposed_height_combo_tid.setter
    def exposed_height_combo_tid(self, exposed_height_combo_tid):
        """Sets the exposed_height_combo_tid of this AvalancheEvaluation2ViewModel.


        :param exposed_height_combo_tid: The exposed_height_combo_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_height_combo_tid = exposed_height_combo_tid

    @property
    def exposed_height_combo_name(self):
        """Gets the exposed_height_combo_name of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The exposed_height_combo_name of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._exposed_height_combo_name

    @exposed_height_combo_name.setter
    def exposed_height_combo_name(self, exposed_height_combo_name):
        """Sets the exposed_height_combo_name of this AvalancheEvaluation2ViewModel.


        :param exposed_height_combo_name: The exposed_height_combo_name of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._exposed_height_combo_name = exposed_height_combo_name

    @property
    def exposed_climate_tid(self):
        """Gets the exposed_climate_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The exposed_climate_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._exposed_climate_tid

    @exposed_climate_tid.setter
    def exposed_climate_tid(self, exposed_climate_tid):
        """Sets the exposed_climate_tid of this AvalancheEvaluation2ViewModel.


        :param exposed_climate_tid: The exposed_climate_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: int
        """

        self._exposed_climate_tid = exposed_climate_tid

    @property
    def exposed_climate_name(self):
        """Gets the exposed_climate_name of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The exposed_climate_name of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: str
        """
        return self._exposed_climate_name

    @exposed_climate_name.setter
    def exposed_climate_name(self, exposed_climate_name):
        """Sets the exposed_climate_name of this AvalancheEvaluation2ViewModel.


        :param exposed_climate_name: The exposed_climate_name of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: str
        """

        self._exposed_climate_name = exposed_climate_name

    @property
    def avalanche_danger_tid(self):
        """Gets the avalanche_danger_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The avalanche_danger_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_danger_tid

    @avalanche_danger_tid.setter
    def avalanche_danger_tid(self, avalanche_danger_tid):
        """Sets the avalanche_danger_tid of this AvalancheEvaluation2ViewModel.


        :param avalanche_danger_tid: The avalanche_danger_tid of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_danger_tid = avalanche_danger_tid

    @property
    def avalanche_eval_problems(self):
        """Gets the avalanche_eval_problems of this AvalancheEvaluation2ViewModel.  # noqa: E501


        :return: The avalanche_eval_problems of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :rtype: list[AvalancheEvalProblemViewModel]
        """
        return self._avalanche_eval_problems

    @avalanche_eval_problems.setter
    def avalanche_eval_problems(self, avalanche_eval_problems):
        """Sets the avalanche_eval_problems of this AvalancheEvaluation2ViewModel.


        :param avalanche_eval_problems: The avalanche_eval_problems of this AvalancheEvaluation2ViewModel.  # noqa: E501
        :type: list[AvalancheEvalProblemViewModel]
        """

        self._avalanche_eval_problems = avalanche_eval_problems

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheEvaluation2ViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheEvaluation2ViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DamageObsDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'damage_type_tid': 'int',
        'damage_position': 'PositionDto',
        'geo_hazard_tid': 'int',
        'usage_flag_tid': 'int',
        'comment': 'str',
        'pictures': 'list[PictureRequestDto]'
    }

    attribute_map = {
        'damage_type_tid': 'DamageTypeTID',
        'damage_position': 'DamagePosition',
        'geo_hazard_tid': 'GeoHazardTID',
        'usage_flag_tid': 'UsageFlagTID',
        'comment': 'Comment',
        'pictures': 'Pictures'
    }

    def __init__(self, damage_type_tid=None, damage_position=None, geo_hazard_tid=None, usage_flag_tid=None, comment=None, pictures=None):  # noqa: E501
        """DamageObsDto - a model defined in Swagger"""  # noqa: E501
        self._damage_type_tid = None
        self._damage_position = None
        self._geo_hazard_tid = None
        self._usage_flag_tid = None
        self._comment = None
        self._pictures = None
        self.discriminator = None
        self.damage_type_tid = damage_type_tid
        if damage_position is not None:
            self.damage_position = damage_position
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if comment is not None:
            self.comment = comment
        if pictures is not None:
            self.pictures = pictures

    @property
    def damage_type_tid(self):
        """Gets the damage_type_tid of this DamageObsDto.  # noqa: E501


        :return: The damage_type_tid of this DamageObsDto.  # noqa: E501
        :rtype: int
        """
        return self._damage_type_tid

    @damage_type_tid.setter
    def damage_type_tid(self, damage_type_tid):
        """Sets the damage_type_tid of this DamageObsDto.


        :param damage_type_tid: The damage_type_tid of this DamageObsDto.  # noqa: E501
        :type: int
        """
        if damage_type_tid is None:
            raise ValueError("Invalid value for `damage_type_tid`, must not be `None`")  # noqa: E501

        self._damage_type_tid = damage_type_tid

    @property
    def damage_position(self):
        """Gets the damage_position of this DamageObsDto.  # noqa: E501


        :return: The damage_position of this DamageObsDto.  # noqa: E501
        :rtype: PositionDto
        """
        return self._damage_position

    @damage_position.setter
    def damage_position(self, damage_position):
        """Sets the damage_position of this DamageObsDto.


        :param damage_position: The damage_position of this DamageObsDto.  # noqa: E501
        :type: PositionDto
        """

        self._damage_position = damage_position

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this DamageObsDto.  # noqa: E501


        :return: The geo_hazard_tid of this DamageObsDto.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this DamageObsDto.


        :param geo_hazard_tid: The geo_hazard_tid of this DamageObsDto.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this DamageObsDto.  # noqa: E501


        :return: The usage_flag_tid of this DamageObsDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this DamageObsDto.


        :param usage_flag_tid: The usage_flag_tid of this DamageObsDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def comment(self):
        """Gets the comment of this DamageObsDto.  # noqa: E501


        :return: The comment of this DamageObsDto.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this DamageObsDto.


        :param comment: The comment of this DamageObsDto.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def pictures(self):
        """Gets the pictures of this DamageObsDto.  # noqa: E501


        :return: The pictures of this DamageObsDto.  # noqa: E501
        :rtype: list[PictureRequestDto]
        """
        return self._pictures

    @pictures.setter
    def pictures(self, pictures):
        """Sets the pictures of this DamageObsDto.


        :param pictures: The pictures of this DamageObsDto.  # noqa: E501
        :type: list[PictureRequestDto]
        """

        self._pictures = pictures

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DamageObsDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DamageObsDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AvalancheEvalProblemViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'avalanche_eval_problem_id': 'int',
        'aval_probability_tid': 'int',
        'aval_probability_name': 'str',
        'aval_trigger_simple_tid': 'int',
        'aval_trigger_simple_name': 'str',
        'destructive_size_ext_tid': 'int',
        'destructive_size_ext_name': 'str',
        'avalanche_ext_tid': 'int',
        'avalanche_ext_name': 'str',
        'aval_cause_tid': 'int',
        'aval_cause_name': 'str',
        'aval_cause_ext_tid': 'int',
        'aval_cause_ext_name': 'str',
        'aval_release_height_tid': 'int',
        'aval_release_height_name': 'str',
        'avalanche_probability_auto_text': 'str',
        'avalanche_problem_auto_text': 'str',
        'comment': 'str'
    }

    attribute_map = {
        'avalanche_eval_problem_id': 'AvalancheEvalProblemID',
        'aval_probability_tid': 'AvalProbabilityTID',
        'aval_probability_name': 'AvalProbabilityName',
        'aval_trigger_simple_tid': 'AvalTriggerSimpleTID',
        'aval_trigger_simple_name': 'AvalTriggerSimpleName',
        'destructive_size_ext_tid': 'DestructiveSizeExtTID',
        'destructive_size_ext_name': 'DestructiveSizeExtName',
        'avalanche_ext_tid': 'AvalancheExtTID',
        'avalanche_ext_name': 'AvalancheExtName',
        'aval_cause_tid': 'AvalCauseTID',
        'aval_cause_name': 'AvalCauseName',
        'aval_cause_ext_tid': 'AvalCauseExtTID',
        'aval_cause_ext_name': 'AvalCauseExtName',
        'aval_release_height_tid': 'AvalReleaseHeightTID',
        'aval_release_height_name': 'AvalReleaseHeightName',
        'avalanche_probability_auto_text': 'AvalancheProbabilityAutoText',
        'avalanche_problem_auto_text': 'AvalancheProblemAutoText',
        'comment': 'Comment'
    }

    def __init__(self, avalanche_eval_problem_id=None, aval_probability_tid=None, aval_probability_name=None, aval_trigger_simple_tid=None, aval_trigger_simple_name=None, destructive_size_ext_tid=None, destructive_size_ext_name=None, avalanche_ext_tid=None, avalanche_ext_name=None, aval_cause_tid=None, aval_cause_name=None, aval_cause_ext_tid=None, aval_cause_ext_name=None, aval_release_height_tid=None, aval_release_height_name=None, avalanche_probability_auto_text=None, avalanche_problem_auto_text=None, comment=None):  # noqa: E501
        """AvalancheEvalProblemViewModel - a model defined in Swagger"""  # noqa: E501
        self._avalanche_eval_problem_id = None
        self._aval_probability_tid = None
        self._aval_probability_name = None
        self._aval_trigger_simple_tid = None
        self._aval_trigger_simple_name = None
        self._destructive_size_ext_tid = None
        self._destructive_size_ext_name = None
        self._avalanche_ext_tid = None
        self._avalanche_ext_name = None
        self._aval_cause_tid = None
        self._aval_cause_name = None
        self._aval_cause_ext_tid = None
        self._aval_cause_ext_name = None
        self._aval_release_height_tid = None
        self._aval_release_height_name = None
        self._avalanche_probability_auto_text = None
        self._avalanche_problem_auto_text = None
        self._comment = None
        self.discriminator = None
        if avalanche_eval_problem_id is not None:
            self.avalanche_eval_problem_id = avalanche_eval_problem_id
        if aval_probability_tid is not None:
            self.aval_probability_tid = aval_probability_tid
        if aval_probability_name is not None:
            self.aval_probability_name = aval_probability_name
        if aval_trigger_simple_tid is not None:
            self.aval_trigger_simple_tid = aval_trigger_simple_tid
        if aval_trigger_simple_name is not None:
            self.aval_trigger_simple_name = aval_trigger_simple_name
        if destructive_size_ext_tid is not None:
            self.destructive_size_ext_tid = destructive_size_ext_tid
        if destructive_size_ext_name is not None:
            self.destructive_size_ext_name = destructive_size_ext_name
        if avalanche_ext_tid is not None:
            self.avalanche_ext_tid = avalanche_ext_tid
        if avalanche_ext_name is not None:
            self.avalanche_ext_name = avalanche_ext_name
        if aval_cause_tid is not None:
            self.aval_cause_tid = aval_cause_tid
        if aval_cause_name is not None:
            self.aval_cause_name = aval_cause_name
        if aval_cause_ext_tid is not None:
            self.aval_cause_ext_tid = aval_cause_ext_tid
        if aval_cause_ext_name is not None:
            self.aval_cause_ext_name = aval_cause_ext_name
        if aval_release_height_tid is not None:
            self.aval_release_height_tid = aval_release_height_tid
        if aval_release_height_name is not None:
            self.aval_release_height_name = aval_release_height_name
        if avalanche_probability_auto_text is not None:
            self.avalanche_probability_auto_text = avalanche_probability_auto_text
        if avalanche_problem_auto_text is not None:
            self.avalanche_problem_auto_text = avalanche_problem_auto_text
        if comment is not None:
            self.comment = comment

    @property
    def avalanche_eval_problem_id(self):
        """Gets the avalanche_eval_problem_id of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The avalanche_eval_problem_id of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_eval_problem_id

    @avalanche_eval_problem_id.setter
    def avalanche_eval_problem_id(self, avalanche_eval_problem_id):
        """Sets the avalanche_eval_problem_id of this AvalancheEvalProblemViewModel.


        :param avalanche_eval_problem_id: The avalanche_eval_problem_id of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_eval_problem_id = avalanche_eval_problem_id

    @property
    def aval_probability_tid(self):
        """Gets the aval_probability_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_probability_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_probability_tid

    @aval_probability_tid.setter
    def aval_probability_tid(self, aval_probability_tid):
        """Sets the aval_probability_tid of this AvalancheEvalProblemViewModel.


        :param aval_probability_tid: The aval_probability_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._aval_probability_tid = aval_probability_tid

    @property
    def aval_probability_name(self):
        """Gets the aval_probability_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_probability_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_probability_name

    @aval_probability_name.setter
    def aval_probability_name(self, aval_probability_name):
        """Sets the aval_probability_name of this AvalancheEvalProblemViewModel.


        :param aval_probability_name: The aval_probability_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._aval_probability_name = aval_probability_name

    @property
    def aval_trigger_simple_tid(self):
        """Gets the aval_trigger_simple_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_trigger_simple_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_trigger_simple_tid

    @aval_trigger_simple_tid.setter
    def aval_trigger_simple_tid(self, aval_trigger_simple_tid):
        """Sets the aval_trigger_simple_tid of this AvalancheEvalProblemViewModel.


        :param aval_trigger_simple_tid: The aval_trigger_simple_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._aval_trigger_simple_tid = aval_trigger_simple_tid

    @property
    def aval_trigger_simple_name(self):
        """Gets the aval_trigger_simple_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_trigger_simple_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_trigger_simple_name

    @aval_trigger_simple_name.setter
    def aval_trigger_simple_name(self, aval_trigger_simple_name):
        """Sets the aval_trigger_simple_name of this AvalancheEvalProblemViewModel.


        :param aval_trigger_simple_name: The aval_trigger_simple_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._aval_trigger_simple_name = aval_trigger_simple_name

    @property
    def destructive_size_ext_tid(self):
        """Gets the destructive_size_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The destructive_size_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._destructive_size_ext_tid

    @destructive_size_ext_tid.setter
    def destructive_size_ext_tid(self, destructive_size_ext_tid):
        """Sets the destructive_size_ext_tid of this AvalancheEvalProblemViewModel.


        :param destructive_size_ext_tid: The destructive_size_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._destructive_size_ext_tid = destructive_size_ext_tid

    @property
    def destructive_size_ext_name(self):
        """Gets the destructive_size_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The destructive_size_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._destructive_size_ext_name

    @destructive_size_ext_name.setter
    def destructive_size_ext_name(self, destructive_size_ext_name):
        """Sets the destructive_size_ext_name of this AvalancheEvalProblemViewModel.


        :param destructive_size_ext_name: The destructive_size_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._destructive_size_ext_name = destructive_size_ext_name

    @property
    def avalanche_ext_tid(self):
        """Gets the avalanche_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The avalanche_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._avalanche_ext_tid

    @avalanche_ext_tid.setter
    def avalanche_ext_tid(self, avalanche_ext_tid):
        """Sets the avalanche_ext_tid of this AvalancheEvalProblemViewModel.


        :param avalanche_ext_tid: The avalanche_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._avalanche_ext_tid = avalanche_ext_tid

    @property
    def avalanche_ext_name(self):
        """Gets the avalanche_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The avalanche_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_ext_name

    @avalanche_ext_name.setter
    def avalanche_ext_name(self, avalanche_ext_name):
        """Sets the avalanche_ext_name of this AvalancheEvalProblemViewModel.


        :param avalanche_ext_name: The avalanche_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_ext_name = avalanche_ext_name

    @property
    def aval_cause_tid(self):
        """Gets the aval_cause_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_cause_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_tid

    @aval_cause_tid.setter
    def aval_cause_tid(self, aval_cause_tid):
        """Sets the aval_cause_tid of this AvalancheEvalProblemViewModel.


        :param aval_cause_tid: The aval_cause_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_tid = aval_cause_tid

    @property
    def aval_cause_name(self):
        """Gets the aval_cause_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_cause_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_name

    @aval_cause_name.setter
    def aval_cause_name(self, aval_cause_name):
        """Sets the aval_cause_name of this AvalancheEvalProblemViewModel.


        :param aval_cause_name: The aval_cause_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_name = aval_cause_name

    @property
    def aval_cause_ext_tid(self):
        """Gets the aval_cause_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_cause_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_cause_ext_tid

    @aval_cause_ext_tid.setter
    def aval_cause_ext_tid(self, aval_cause_ext_tid):
        """Sets the aval_cause_ext_tid of this AvalancheEvalProblemViewModel.


        :param aval_cause_ext_tid: The aval_cause_ext_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._aval_cause_ext_tid = aval_cause_ext_tid

    @property
    def aval_cause_ext_name(self):
        """Gets the aval_cause_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_cause_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_cause_ext_name

    @aval_cause_ext_name.setter
    def aval_cause_ext_name(self, aval_cause_ext_name):
        """Sets the aval_cause_ext_name of this AvalancheEvalProblemViewModel.


        :param aval_cause_ext_name: The aval_cause_ext_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._aval_cause_ext_name = aval_cause_ext_name

    @property
    def aval_release_height_tid(self):
        """Gets the aval_release_height_tid of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_release_height_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aval_release_height_tid

    @aval_release_height_tid.setter
    def aval_release_height_tid(self, aval_release_height_tid):
        """Sets the aval_release_height_tid of this AvalancheEvalProblemViewModel.


        :param aval_release_height_tid: The aval_release_height_tid of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: int
        """

        self._aval_release_height_tid = aval_release_height_tid

    @property
    def aval_release_height_name(self):
        """Gets the aval_release_height_name of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The aval_release_height_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._aval_release_height_name

    @aval_release_height_name.setter
    def aval_release_height_name(self, aval_release_height_name):
        """Sets the aval_release_height_name of this AvalancheEvalProblemViewModel.


        :param aval_release_height_name: The aval_release_height_name of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._aval_release_height_name = aval_release_height_name

    @property
    def avalanche_probability_auto_text(self):
        """Gets the avalanche_probability_auto_text of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The avalanche_probability_auto_text of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_probability_auto_text

    @avalanche_probability_auto_text.setter
    def avalanche_probability_auto_text(self, avalanche_probability_auto_text):
        """Sets the avalanche_probability_auto_text of this AvalancheEvalProblemViewModel.


        :param avalanche_probability_auto_text: The avalanche_probability_auto_text of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_probability_auto_text = avalanche_probability_auto_text

    @property
    def avalanche_problem_auto_text(self):
        """Gets the avalanche_problem_auto_text of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The avalanche_problem_auto_text of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._avalanche_problem_auto_text

    @avalanche_problem_auto_text.setter
    def avalanche_problem_auto_text(self, avalanche_problem_auto_text):
        """Sets the avalanche_problem_auto_text of this AvalancheEvalProblemViewModel.


        :param avalanche_problem_auto_text: The avalanche_problem_auto_text of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._avalanche_problem_auto_text = avalanche_problem_auto_text

    @property
    def comment(self):
        """Gets the comment of this AvalancheEvalProblemViewModel.  # noqa: E501


        :return: The comment of this AvalancheEvalProblemViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AvalancheEvalProblemViewModel.


        :param comment: The comment of this AvalancheEvalProblemViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AvalancheEvalProblemViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AvalancheEvalProblemViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AttachmentViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'reg_id': 'int',
        'picture_id': 'int',
        'photographer': 'str',
        'copyright': 'str',
        'aspect': 'int',
        'geo_hazard_tid': 'int',
        'geo_hazard_name': 'str',
        'registration_tid': 'int',
        'registration_name': 'str',
        'comment': 'str',
        'attachment_file_name': 'str',
        'attachment_mime_type': 'str',
        'is_main_attachment': 'bool'
    }

    attribute_map = {
        'reg_id': 'RegID',
        'picture_id': 'PictureID',
        'photographer': 'Photographer',
        'copyright': 'Copyright',
        'aspect': 'Aspect',
        'geo_hazard_tid': 'GeoHazardTID',
        'geo_hazard_name': 'GeoHazardName',
        'registration_tid': 'RegistrationTID',
        'registration_name': 'RegistrationName',
        'comment': 'Comment',
        'attachment_file_name': 'AttachmentFileName',
        'attachment_mime_type': 'AttachmentMimeType',
        'is_main_attachment': 'IsMainAttachment'
    }

    def __init__(self, reg_id=None, picture_id=None, photographer=None, copyright=None, aspect=None, geo_hazard_tid=None, geo_hazard_name=None, registration_tid=None, registration_name=None, comment=None, attachment_file_name=None, attachment_mime_type=None, is_main_attachment=None):  # noqa: E501
        """AttachmentViewModel - a model defined in Swagger"""  # noqa: E501
        self._reg_id = None
        self._picture_id = None
        self._photographer = None
        self._copyright = None
        self._aspect = None
        self._geo_hazard_tid = None
        self._geo_hazard_name = None
        self._registration_tid = None
        self._registration_name = None
        self._comment = None
        self._attachment_file_name = None
        self._attachment_mime_type = None
        self._is_main_attachment = None
        self.discriminator = None
        if reg_id is not None:
            self.reg_id = reg_id
        if picture_id is not None:
            self.picture_id = picture_id
        if photographer is not None:
            self.photographer = photographer
        if copyright is not None:
            self.copyright = copyright
        if aspect is not None:
            self.aspect = aspect
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if geo_hazard_name is not None:
            self.geo_hazard_name = geo_hazard_name
        if registration_tid is not None:
            self.registration_tid = registration_tid
        if registration_name is not None:
            self.registration_name = registration_name
        if comment is not None:
            self.comment = comment
        if attachment_file_name is not None:
            self.attachment_file_name = attachment_file_name
        if attachment_mime_type is not None:
            self.attachment_mime_type = attachment_mime_type
        if is_main_attachment is not None:
            self.is_main_attachment = is_main_attachment

    @property
    def reg_id(self):
        """Gets the reg_id of this AttachmentViewModel.  # noqa: E501


        :return: The reg_id of this AttachmentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._reg_id

    @reg_id.setter
    def reg_id(self, reg_id):
        """Sets the reg_id of this AttachmentViewModel.


        :param reg_id: The reg_id of this AttachmentViewModel.  # noqa: E501
        :type: int
        """

        self._reg_id = reg_id

    @property
    def picture_id(self):
        """Gets the picture_id of this AttachmentViewModel.  # noqa: E501


        :return: The picture_id of this AttachmentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._picture_id

    @picture_id.setter
    def picture_id(self, picture_id):
        """Sets the picture_id of this AttachmentViewModel.


        :param picture_id: The picture_id of this AttachmentViewModel.  # noqa: E501
        :type: int
        """

        self._picture_id = picture_id

    @property
    def photographer(self):
        """Gets the photographer of this AttachmentViewModel.  # noqa: E501


        :return: The photographer of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._photographer

    @photographer.setter
    def photographer(self, photographer):
        """Sets the photographer of this AttachmentViewModel.


        :param photographer: The photographer of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._photographer = photographer

    @property
    def copyright(self):
        """Gets the copyright of this AttachmentViewModel.  # noqa: E501


        :return: The copyright of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._copyright

    @copyright.setter
    def copyright(self, copyright):
        """Sets the copyright of this AttachmentViewModel.


        :param copyright: The copyright of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._copyright = copyright

    @property
    def aspect(self):
        """Gets the aspect of this AttachmentViewModel.  # noqa: E501


        :return: The aspect of this AttachmentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._aspect

    @aspect.setter
    def aspect(self, aspect):
        """Sets the aspect of this AttachmentViewModel.


        :param aspect: The aspect of this AttachmentViewModel.  # noqa: E501
        :type: int
        """

        self._aspect = aspect

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this AttachmentViewModel.  # noqa: E501


        :return: The geo_hazard_tid of this AttachmentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this AttachmentViewModel.


        :param geo_hazard_tid: The geo_hazard_tid of this AttachmentViewModel.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def geo_hazard_name(self):
        """Gets the geo_hazard_name of this AttachmentViewModel.  # noqa: E501


        :return: The geo_hazard_name of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._geo_hazard_name

    @geo_hazard_name.setter
    def geo_hazard_name(self, geo_hazard_name):
        """Sets the geo_hazard_name of this AttachmentViewModel.


        :param geo_hazard_name: The geo_hazard_name of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._geo_hazard_name = geo_hazard_name

    @property
    def registration_tid(self):
        """Gets the registration_tid of this AttachmentViewModel.  # noqa: E501


        :return: The registration_tid of this AttachmentViewModel.  # noqa: E501
        :rtype: int
        """
        return self._registration_tid

    @registration_tid.setter
    def registration_tid(self, registration_tid):
        """Sets the registration_tid of this AttachmentViewModel.


        :param registration_tid: The registration_tid of this AttachmentViewModel.  # noqa: E501
        :type: int
        """

        self._registration_tid = registration_tid

    @property
    def registration_name(self):
        """Gets the registration_name of this AttachmentViewModel.  # noqa: E501


        :return: The registration_name of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._registration_name

    @registration_name.setter
    def registration_name(self, registration_name):
        """Sets the registration_name of this AttachmentViewModel.


        :param registration_name: The registration_name of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._registration_name = registration_name

    @property
    def comment(self):
        """Gets the comment of this AttachmentViewModel.  # noqa: E501


        :return: The comment of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AttachmentViewModel.


        :param comment: The comment of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def attachment_file_name(self):
        """Gets the attachment_file_name of this AttachmentViewModel.  # noqa: E501


        :return: The attachment_file_name of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._attachment_file_name

    @attachment_file_name.setter
    def attachment_file_name(self, attachment_file_name):
        """Sets the attachment_file_name of this AttachmentViewModel.


        :param attachment_file_name: The attachment_file_name of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._attachment_file_name = attachment_file_name

    @property
    def attachment_mime_type(self):
        """Gets the attachment_mime_type of this AttachmentViewModel.  # noqa: E501


        :return: The attachment_mime_type of this AttachmentViewModel.  # noqa: E501
        :rtype: str
        """
        return self._attachment_mime_type

    @attachment_mime_type.setter
    def attachment_mime_type(self, attachment_mime_type):
        """Sets the attachment_mime_type of this AttachmentViewModel.


        :param attachment_mime_type: The attachment_mime_type of this AttachmentViewModel.  # noqa: E501
        :type: str
        """

        self._attachment_mime_type = attachment_mime_type

    @property
    def is_main_attachment(self):
        """Gets the is_main_attachment of this AttachmentViewModel.  # noqa: E501


        :return: The is_main_attachment of this AttachmentViewModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_main_attachment

    @is_main_attachment.setter
    def is_main_attachment(self, is_main_attachment):
        """Sets the is_main_attachment of this AttachmentViewModel.


        :param is_main_attachment: The is_main_attachment of this AttachmentViewModel.  # noqa: E501
        :type: bool
        """

        self._is_main_attachment = is_main_attachment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachmentViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class WaterLevelViewModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'water_level_described': 'str',
        'water_level_value': 'float',
        'water_level_ref_tid': 'int',
        'water_level_ref_name': 'str',
        'comment': 'str',
        'measured_discharge': 'float',
        'is_river': 'bool'
    }

    attribute_map = {
        'water_level_described': 'WaterLevelDescribed',
        'water_level_value': 'WaterLevelValue',
        'water_level_ref_tid': 'WaterLevelRefTID',
        'water_level_ref_name': 'WaterLevelRefName',
        'comment': 'Comment',
        'measured_discharge': 'MeasuredDischarge',
        'is_river': 'IsRiver'
    }

    def __init__(self, water_level_described=None, water_level_value=None, water_level_ref_tid=None, water_level_ref_name=None, comment=None, measured_discharge=None, is_river=None):  # noqa: E501
        """WaterLevelViewModel - a model defined in Swagger"""  # noqa: E501
        self._water_level_described = None
        self._water_level_value = None
        self._water_level_ref_tid = None
        self._water_level_ref_name = None
        self._comment = None
        self._measured_discharge = None
        self._is_river = None
        self.discriminator = None
        if water_level_described is not None:
            self.water_level_described = water_level_described
        if water_level_value is not None:
            self.water_level_value = water_level_value
        if water_level_ref_tid is not None:
            self.water_level_ref_tid = water_level_ref_tid
        if water_level_ref_name is not None:
            self.water_level_ref_name = water_level_ref_name
        if comment is not None:
            self.comment = comment
        if measured_discharge is not None:
            self.measured_discharge = measured_discharge
        if is_river is not None:
            self.is_river = is_river

    @property
    def water_level_described(self):
        """Gets the water_level_described of this WaterLevelViewModel.  # noqa: E501


        :return: The water_level_described of this WaterLevelViewModel.  # noqa: E501
        :rtype: str
        """
        return self._water_level_described

    @water_level_described.setter
    def water_level_described(self, water_level_described):
        """Sets the water_level_described of this WaterLevelViewModel.


        :param water_level_described: The water_level_described of this WaterLevelViewModel.  # noqa: E501
        :type: str
        """

        self._water_level_described = water_level_described

    @property
    def water_level_value(self):
        """Gets the water_level_value of this WaterLevelViewModel.  # noqa: E501


        :return: The water_level_value of this WaterLevelViewModel.  # noqa: E501
        :rtype: float
        """
        return self._water_level_value

    @water_level_value.setter
    def water_level_value(self, water_level_value):
        """Sets the water_level_value of this WaterLevelViewModel.


        :param water_level_value: The water_level_value of this WaterLevelViewModel.  # noqa: E501
        :type: float
        """

        self._water_level_value = water_level_value

    @property
    def water_level_ref_tid(self):
        """Gets the water_level_ref_tid of this WaterLevelViewModel.  # noqa: E501


        :return: The water_level_ref_tid of this WaterLevelViewModel.  # noqa: E501
        :rtype: int
        """
        return self._water_level_ref_tid

    @water_level_ref_tid.setter
    def water_level_ref_tid(self, water_level_ref_tid):
        """Sets the water_level_ref_tid of this WaterLevelViewModel.


        :param water_level_ref_tid: The water_level_ref_tid of this WaterLevelViewModel.  # noqa: E501
        :type: int
        """

        self._water_level_ref_tid = water_level_ref_tid

    @property
    def water_level_ref_name(self):
        """Gets the water_level_ref_name of this WaterLevelViewModel.  # noqa: E501


        :return: The water_level_ref_name of this WaterLevelViewModel.  # noqa: E501
        :rtype: str
        """
        return self._water_level_ref_name

    @water_level_ref_name.setter
    def water_level_ref_name(self, water_level_ref_name):
        """Sets the water_level_ref_name of this WaterLevelViewModel.


        :param water_level_ref_name: The water_level_ref_name of this WaterLevelViewModel.  # noqa: E501
        :type: str
        """

        self._water_level_ref_name = water_level_ref_name

    @property
    def comment(self):
        """Gets the comment of this WaterLevelViewModel.  # noqa: E501


        :return: The comment of this WaterLevelViewModel.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this WaterLevelViewModel.


        :param comment: The comment of this WaterLevelViewModel.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def measured_discharge(self):
        """Gets the measured_discharge of this WaterLevelViewModel.  # noqa: E501


        :return: The measured_discharge of this WaterLevelViewModel.  # noqa: E501
        :rtype: float
        """
        return self._measured_discharge

    @measured_discharge.setter
    def measured_discharge(self, measured_discharge):
        """Sets the measured_discharge of this WaterLevelViewModel.


        :param measured_discharge: The measured_discharge of this WaterLevelViewModel.  # noqa: E501
        :type: float
        """

        self._measured_discharge = measured_discharge

    @property
    def is_river(self):
        """Gets the is_river of this WaterLevelViewModel.  # noqa: E501


        :return: The is_river of this WaterLevelViewModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_river

    @is_river.setter
    def is_river(self, is_river):
        """Sets the is_river of this WaterLevelViewModel.


        :param is_river: The is_river of this WaterLevelViewModel.  # noqa: E501
        :type: bool
        """

        self._is_river = is_river

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WaterLevelViewModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WaterLevelViewModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    RegObs API

      ## Introduction    RegObs is a tool for collecting observations and events   related to natural hazards. It is currently used by the   Norwegian flood, landslide and avalanche warning service in   Norway, but the data is openly available for anyone through this API.    Regobs has been developed by the Norwegian Water resources and   Energy Directorate (NVE), in collaboration with the Norwegian   Meteorological Institute (MET) and the Norwegian Public Roads   Administration (NPRA).    You can check out our representation of the data at [regobs.no](http://regobs.no).    ## Authentication    Some endpoints require an api key.  You can get an API key by sending an email to   [raek@nve.no](mailto:raek@nve.no?subject=RegObs%20API%20Key).  To use the api key with the swagger ui, fill in the api\\_key input above.   It should then be included with every request in the   `regObs_apptoken` header.    ## Getting started    Get the last 10 observations using python:    ```python  import requests  r = requests.post('https://api.regobs.no/v4/Search',       data={'NumberOfRecords': 10},      headers={'Content-Type': 'application/json'}  )  data = r.json()  print(len(data))  # 10  ```      # noqa: E501

    OpenAPI spec version: v4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PictureRequestDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'photographer': 'str',
        'copyright': 'str',
        'aspect': 'int',
        'geo_hazard_tid': 'int',
        'usage_flag_tid': 'int',
        'registration_tid': 'int',
        'picture_comment': 'str',
        'picture_image_base64': 'str',
        'attachment_upload_id': 'str',
        'is_main_attachment': 'bool'
    }

    attribute_map = {
        'photographer': 'Photographer',
        'copyright': 'Copyright',
        'aspect': 'Aspect',
        'geo_hazard_tid': 'GeoHazardTID',
        'usage_flag_tid': 'UsageFlagTID',
        'registration_tid': 'RegistrationTID',
        'picture_comment': 'PictureComment',
        'picture_image_base64': 'PictureImageBase64',
        'attachment_upload_id': 'AttachmentUploadId',
        'is_main_attachment': 'IsMainAttachment'
    }

    def __init__(self, photographer=None, copyright=None, aspect=None, geo_hazard_tid=None, usage_flag_tid=None, registration_tid=None, picture_comment=None, picture_image_base64=None, attachment_upload_id=None, is_main_attachment=None):  # noqa: E501
        """PictureRequestDto - a model defined in Swagger"""  # noqa: E501
        self._photographer = None
        self._copyright = None
        self._aspect = None
        self._geo_hazard_tid = None
        self._usage_flag_tid = None
        self._registration_tid = None
        self._picture_comment = None
        self._picture_image_base64 = None
        self._attachment_upload_id = None
        self._is_main_attachment = None
        self.discriminator = None
        if photographer is not None:
            self.photographer = photographer
        if copyright is not None:
            self.copyright = copyright
        if aspect is not None:
            self.aspect = aspect
        if geo_hazard_tid is not None:
            self.geo_hazard_tid = geo_hazard_tid
        if usage_flag_tid is not None:
            self.usage_flag_tid = usage_flag_tid
        if registration_tid is not None:
            self.registration_tid = registration_tid
        if picture_comment is not None:
            self.picture_comment = picture_comment
        if picture_image_base64 is not None:
            self.picture_image_base64 = picture_image_base64
        if attachment_upload_id is not None:
            self.attachment_upload_id = attachment_upload_id
        if is_main_attachment is not None:
            self.is_main_attachment = is_main_attachment

    @property
    def photographer(self):
        """Gets the photographer of this PictureRequestDto.  # noqa: E501

        Navn på fotograf.  # noqa: E501

        :return: The photographer of this PictureRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._photographer

    @photographer.setter
    def photographer(self, photographer):
        """Sets the photographer of this PictureRequestDto.

        Navn på fotograf.  # noqa: E501

        :param photographer: The photographer of this PictureRequestDto.  # noqa: E501
        :type: str
        """

        self._photographer = photographer

    @property
    def copyright(self):
        """Gets the copyright of this PictureRequestDto.  # noqa: E501

        Rettigheter til bilde.  # noqa: E501

        :return: The copyright of this PictureRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._copyright

    @copyright.setter
    def copyright(self, copyright):
        """Sets the copyright of this PictureRequestDto.

        Rettigheter til bilde.  # noqa: E501

        :param copyright: The copyright of this PictureRequestDto.  # noqa: E501
        :type: str
        """

        self._copyright = copyright

    @property
    def aspect(self):
        """Gets the aspect of this PictureRequestDto.  # noqa: E501

        Hvilken himmelretning peker bilde. Gis i grader slik gitt på kompass. 0 er nord og 90 er øst osv.  # noqa: E501

        :return: The aspect of this PictureRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._aspect

    @aspect.setter
    def aspect(self, aspect):
        """Sets the aspect of this PictureRequestDto.

        Hvilken himmelretning peker bilde. Gis i grader slik gitt på kompass. 0 er nord og 90 er øst osv.  # noqa: E501

        :param aspect: The aspect of this PictureRequestDto.  # noqa: E501
        :type: int
        """

        self._aspect = aspect

    @property
    def geo_hazard_tid(self):
        """Gets the geo_hazard_tid of this PictureRequestDto.  # noqa: E501

        Sett naturfare. Tabellen brukes av alle naturfarer (snø, jord, vann, is). The GeoHazardKD unique identifier  # noqa: E501

        :return: The geo_hazard_tid of this PictureRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._geo_hazard_tid

    @geo_hazard_tid.setter
    def geo_hazard_tid(self, geo_hazard_tid):
        """Sets the geo_hazard_tid of this PictureRequestDto.

        Sett naturfare. Tabellen brukes av alle naturfarer (snø, jord, vann, is). The GeoHazardKD unique identifier  # noqa: E501

        :param geo_hazard_tid: The geo_hazard_tid of this PictureRequestDto.  # noqa: E501
        :type: int
        """

        self._geo_hazard_tid = geo_hazard_tid

    @property
    def usage_flag_tid(self):
        """Gets the usage_flag_tid of this PictureRequestDto.  # noqa: E501

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :return: The usage_flag_tid of this PictureRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._usage_flag_tid

    @usage_flag_tid.setter
    def usage_flag_tid(self, usage_flag_tid):
        """Sets the usage_flag_tid of this PictureRequestDto.

        Bruksflagg er ikke implementert enda. Hensikten er å kunne flagge en observasjon som godkjent, underkjent, overført historisk database mm. The UsageFlagKD unique identifier  # noqa: E501

        :param usage_flag_tid: The usage_flag_tid of this PictureRequestDto.  # noqa: E501
        :type: int
        """

        self._usage_flag_tid = usage_flag_tid

    @property
    def registration_tid(self):
        """Gets the registration_tid of this PictureRequestDto.  # noqa: E501

        Hva er bildet av. Dette feltet relaterer bildet til en observasjonstype. Feks værobservasjon, faretegn, osv. The RegistrationKD unique identifier  # noqa: E501

        :return: The registration_tid of this PictureRequestDto.  # noqa: E501
        :rtype: int
        """
        return self._registration_tid

    @registration_tid.setter
    def registration_tid(self, registration_tid):
        """Sets the registration_tid of this PictureRequestDto.

        Hva er bildet av. Dette feltet relaterer bildet til en observasjonstype. Feks værobservasjon, faretegn, osv. The RegistrationKD unique identifier  # noqa: E501

        :param registration_tid: The registration_tid of this PictureRequestDto.  # noqa: E501
        :type: int
        """

        self._registration_tid = registration_tid

    @property
    def picture_comment(self):
        """Gets the picture_comment of this PictureRequestDto.  # noqa: E501

        Kommentarfelt for bildet. F.eks for å beskrive det.  # noqa: E501

        :return: The picture_comment of this PictureRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._picture_comment

    @picture_comment.setter
    def picture_comment(self, picture_comment):
        """Sets the picture_comment of this PictureRequestDto.

        Kommentarfelt for bildet. F.eks for å beskrive det.  # noqa: E501

        :param picture_comment: The picture_comment of this PictureRequestDto.  # noqa: E501
        :type: str
        """

        self._picture_comment = picture_comment

    @property
    def picture_image_base64(self):
        """Gets the picture_image_base64 of this PictureRequestDto.  # noqa: E501

        Billed objektet.  # noqa: E501

        :return: The picture_image_base64 of this PictureRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._picture_image_base64

    @picture_image_base64.setter
    def picture_image_base64(self, picture_image_base64):
        """Sets the picture_image_base64 of this PictureRequestDto.

        Billed objektet.  # noqa: E501

        :param picture_image_base64: The picture_image_base64 of this PictureRequestDto.  # noqa: E501
        :type: str
        """

        self._picture_image_base64 = picture_image_base64

    @property
    def attachment_upload_id(self):
        """Gets the attachment_upload_id of this PictureRequestDto.  # noqa: E501

        If attachment is uploaded before sending registration, set AttachmentUploadId  # noqa: E501

        :return: The attachment_upload_id of this PictureRequestDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_upload_id

    @attachment_upload_id.setter
    def attachment_upload_id(self, attachment_upload_id):
        """Sets the attachment_upload_id of this PictureRequestDto.

        If attachment is uploaded before sending registration, set AttachmentUploadId  # noqa: E501

        :param attachment_upload_id: The attachment_upload_id of this PictureRequestDto.  # noqa: E501
        :type: str
        """

        self._attachment_upload_id = attachment_upload_id

    @property
    def is_main_attachment(self):
        """Gets the is_main_attachment of this PictureRequestDto.  # noqa: E501

        Om bildet skal vises først i registreringen, eller ikke  # noqa: E501

        :return: The is_main_attachment of this PictureRequestDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_main_attachment

    @is_main_attachment.setter
    def is_main_attachment(self, is_main_attachment):
        """Sets the is_main_attachment of this PictureRequestDto.

        Om bildet skal vises først i registreringen, eller ikke  # noqa: E501

        :param is_main_attachment: The is_main_attachment of this PictureRequestDto.  # noqa: E501
        :type: bool
        """

        self._is_main_attachment = is_main_attachment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PictureRequestDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PictureRequestDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
